#!/bin/sh
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
# Authors: Mischa Sall\'e, Oscar Koeroo
#      NIKHEF Amsterdam, the Netherlands
#      <grid-mw-security@nikhef.nl>
#

# Default target and source
TARGET=llrun
SOURCE=llrun.c

# Default compiler
CC=${CC:-cc}

CFLAGS=${CFLAGS:-}

# Determine platform and type of C compiler
PLATFORM=`uname -s`
$CC --version 2>/dev/null | grep -i gcc > /dev/null && GCC=yes || GCC=no

# Set platform dependent linker flags
if [ "$PLATFORM" = "Darwin" ]
then
    EXTLIB=libvomsfix.dylib
    LDEXTRA="-Wl,-dylib_install_name -Wl,./$EXTLIB"
else
    EXTLIB=libvomsfix.so
    LDEXTRA="-Wl,-soname,./$EXTLIB"
fi

# Compile: only gnu with ELF supports rdynamic, seems OK on Darwin...
if [ \( "$PLATFORM" = "Linux" -o "$PLATFORM" = "Darwin" \) -a "$GCC" = "yes" ]
then
    cmd="$CC $CFLAGS -Wall -rdynamic -ldl -o $TARGET $SOURCE"
else
    cmd="$CC $CFLAGS -fPIC -shared $LDEXTRA -o $EXTLIB vomsfix.c && \
	 $CC $CFLAGS -L. -lvomsfix -ldl -o $TARGET $SOURCE"
fi

# Print and execute compile command
echo $cmd
eval $cmd



